"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExecutableAdapter = void 0;
const tslib_1 = require("tslib");
const CP = tslib_1.__importStar(require("child_process"));
const npm_which_1 = tslib_1.__importDefault(require("npm-which"));
const villa = tslib_1.__importStar(require("villa"));
class ExecutableAdapter {
    constructor() {
        this.type = 'executable';
    }
    async runScript({ cwd, source, parameters, resourcesPath: resourcePath, resourcesBaseURL: resourceBaseURL, onOutput, onError, }) {
        var _a;
        const which = npm_which_1.default(cwd);
        try {
            let commandPath = await villa.call(which, source);
            let cp = CP.spawn(commandPath, {
                env: {
                    ...process.env,
                    RESOURCE_PATH: resourcePath,
                    RESOURCE_BASE_URL: resourceBaseURL,
                    ...parameters,
                },
            });
            cp.stdout.on('data', (buffer) => {
                onOutput(buffer.toString());
            });
            cp.stderr.on('data', (buffer) => {
                onError(buffer.toString());
            });
            await villa.awaitable(cp);
            return { result: 'done', message: '' };
        }
        catch (error) {
            return { result: 'unknown-error', message: (_a = error.message) !== null && _a !== void 0 ? _a : String(error) };
        }
    }
}
exports.ExecutableAdapter = ExecutableAdapter;
//# sourceMappingURL=executable-adapter.js.map